@@ -62,7 +62,8 @@
 typedef enum {
   EPHY_PROFILE_DIR_UNKNOWN,
   EPHY_PROFILE_DIR_DEFAULT,
-  EPHY_PROFILE_DIR_WEB_APP
+  EPHY_PROFILE_DIR_WEB_APP,
+  EPHY_PROFILE_DIR_TEST
 } EphyProfileDirType;
 
 static GHashTable *files;
@@ -142,12 +143,17 @@ ephy_file_get_downloads_dir (void)
   download_dir = g_settings_get_string (EPHY_SETTINGS_STATE,
                                         EPHY_PREFS_STATE_DOWNLOAD_DIR);
 
-  if (!g_strcmp0 (download_dir, "Downloads") ||
+  if (g_strcmp0 (download_dir, "Downloads") == 0 ||
       !g_path_is_absolute (download_dir) ||
-      ephy_is_running_inside_flatpak ())
-    download_dir = ephy_file_download_dir ();
-  else if (!g_strcmp0 (download_dir, "Desktop"))
-    download_dir = ephy_file_desktop_dir ();
+      ephy_is_running_inside_flatpak ()) {
+    g_free (download_dir);
+    return ephy_file_download_dir ();
+  }
+
+  if (g_strcmp0 (download_dir, "Desktop") == 0) {
+    g_free (download_dir);
+    return ephy_file_desktop_dir ();
+  }
 
   return download_dir;
 }
@@ -240,7 +246,7 @@ ephy_dot_dir (void)
 gboolean
 ephy_dot_dir_is_default (void)
 {
-  return dot_dir_type == EPHY_PROFILE_DIR_DEFAULT;
+  return dot_dir_type == EPHY_PROFILE_DIR_DEFAULT || dot_dir_type == EPHY_PROFILE_DIR_TEST;
 }
 
 /**
@@ -266,7 +272,9 @@ ephy_dot_dir_is_web_application (void)
 char *
 ephy_default_dot_dir (void)
 {
-  return g_build_filename (g_get_user_config_dir (), "epiphany", NULL);
+  return dot_dir_type == EPHY_PROFILE_DIR_TEST ?
+    g_strdup (ephy_dot_dir ()) :
+    g_build_filename (g_get_user_config_dir (), "epiphany", NULL);
 }
 
 /**
@@ -297,7 +305,7 @@ ephy_file_helpers_init (const char          *profile_dir,
                                  (GDestroyNotify)g_free);
 
   keep_directory = flags & EPHY_FILE_HELPERS_KEEP_DIR;
-  private_profile = flags & EPHY_FILE_HELPERS_PRIVATE_PROFILE;
+  private_profile = (flags & EPHY_FILE_HELPERS_PRIVATE_PROFILE || flags & EPHY_FILE_HELPERS_TESTING_MODE);
   steal_data_from_profile = flags & EPHY_FILE_HELPERS_STEAL_DATA;
 
   if (profile_dir != NULL && !steal_data_from_profile) {
@@ -328,11 +336,13 @@ ephy_file_helpers_init (const char          *profile_dir,
     dot_dir = g_build_filename (ephy_file_tmp_dir (),
                                 "epiphany",
                                 NULL);
+    if (flags & EPHY_FILE_HELPERS_TESTING_MODE)
+      dot_dir_type = EPHY_PROFILE_DIR_TEST;
   }
 
   if (dot_dir == NULL) {
-    dot_dir = ephy_default_dot_dir ();
     dot_dir_type = EPHY_PROFILE_DIR_DEFAULT;
+    dot_dir = ephy_default_dot_dir ();
   }
 
   if (flags & EPHY_FILE_HELPERS_ENSURE_EXISTS)
@@ -1041,3 +1051,33 @@ ephy_open_incognito_window (const char *uri)
 
   g_free (command);
 }
+
+gboolean
+ephy_file_launch_via_uri_handler (const char *uri)
+{
+  GdkDisplay *display;
+  GdkAppLaunchContext *context;
+  GError *error = NULL;
+
+  display = gdk_display_get_default ();
+  context = gdk_display_get_app_launch_context (display);
+
+  g_app_info_launch_default_for_uri (uri, G_APP_LAUNCH_CONTEXT (context), &error);
+
+  if (error != NULL) {
+    g_warning ("Failed to launch handler for URI %s: %s", uri, error->message);
+    g_error_free (error);
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+gboolean
+ephy_file_launch_file_via_uri_handler (GFile *file)
+{
+  const char *uri;
+
+  uri = g_file_get_uri (file);
+  return ephy_file_launch_via_uri_handler (uri);
+}
