@@ -331,8 +331,7 @@ ephy_location_entry_get_preferred_height (GtkWidget *widget,
 }
 
 static void
-ephy_location_entry_copy_clipboard (GtkEntry *entry,
-                                    gpointer  user_data)
+ephy_location_entry_do_copy_clipboard (GtkEntry *entry)
 {
   char *text;
   gint start;
@@ -355,6 +354,15 @@ ephy_location_entry_copy_clipboard (GtkEntry *entry,
   g_free (text);
 }
 
+static void
+ephy_location_entry_copy_clipboard (GtkEntry *entry,
+                                    gpointer  user_data)
+{
+  ephy_location_entry_do_copy_clipboard (entry);
+
+  g_signal_stop_emission_by_name (entry, "copy-clipboard");
+}
+
 static void
 ephy_location_entry_cut_clipboard (GtkEntry *entry)
 {
@@ -363,8 +371,10 @@ ephy_location_entry_cut_clipboard (GtkEntry *entry)
     return;
   }
 
-  ephy_location_entry_copy_clipboard (entry, NULL);
+  ephy_location_entry_do_copy_clipboard (entry);
   gtk_editable_delete_selection (GTK_EDITABLE (entry));
+
+  g_signal_stop_emission_by_name (entry, "cut-clipboard");
 }
 
 static void
@@ -806,6 +816,7 @@ static void
 ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 {
   GtkWidget *button_box;
+  GtkStyleContext *context;
 
   LOG ("EphyLocationEntry constructing contents %p", entry);
 
@@ -835,6 +846,9 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
   gtk_container_add (GTK_CONTAINER(entry->bookmark_event_box), entry->bookmark);
   gtk_box_pack_end (GTK_BOX (button_box), entry->bookmark_event_box, FALSE, FALSE, 6);
 
+  context = gtk_widget_get_style_context (entry->bookmark);
+  gtk_style_context_add_class (context, "entry_icon");
+
   /* Reader Mode */
   entry->reader_mode_event_box = gtk_event_box_new ();
   entry->reader_mode = gtk_image_new_from_icon_name ("ephy-reader-mode-symbolic", GTK_ICON_SIZE_MENU);
@@ -842,6 +856,9 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
   gtk_container_add (GTK_CONTAINER(entry->reader_mode_event_box), entry->reader_mode);
   gtk_box_pack_end (GTK_BOX (button_box), entry->reader_mode_event_box, FALSE, FALSE, 6);
 
+  context = gtk_widget_get_style_context (entry->reader_mode);
+  gtk_style_context_add_class (context, "entry_icon");
+
   g_object_connect (entry->url_entry,
                     "signal::icon-press", G_CALLBACK (icon_button_icon_press_event_cb), entry,
                     "signal::populate-popup", G_CALLBACK (entry_populate_popup_cb), entry,
@@ -978,7 +995,7 @@ extracell_data_func (GtkCellLayout   *cell_layout,
 
   if (is_bookmark)
     g_object_set (cell,
-                  "icon-name", "user-bookmarks-symbolic",
+                  "icon-name", "starred-symbolic",
                   NULL);
 
   g_value_init (&visible, G_TYPE_BOOLEAN);
