@@ -57,7 +57,7 @@ server_callback (SoupServer        *server,
 {
   soup_message_set_status (msg, SOUP_STATUS_OK);
 
-  if (g_str_equal (path, "/cancelled"))
+  if (!strcmp (path, "/cancelled"))
     soup_message_set_status (msg, SOUP_STATUS_CANT_CONNECT);
 
   soup_message_body_append (msg->response_body, SOUP_MEMORY_STATIC,
@@ -164,7 +164,7 @@ main (int argc, char *argv[])
   ephy_debug_init ();
 
   if (!ephy_file_helpers_init (NULL,
-                               EPHY_FILE_HELPERS_PRIVATE_PROFILE | EPHY_FILE_HELPERS_ENSURE_EXISTS,
+                               EPHY_FILE_HELPERS_TESTING_MODE | EPHY_FILE_HELPERS_ENSURE_EXISTS,
                                NULL)) {
     g_debug ("Something wrong happened with ephy_file_helpers_init()");
     return -1;
