@@ -1,23 +1,21 @@
-/* vim: set sw=2 ts=2 sts=2 et: */
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * ephy-embed-shell-test.c
- * This file is part of Epiphany
+ *  Copyright © 2012 Igalia S.L.
  *
- * Copyright © 2012 - Igalia S.L.
+ *  This file is part of Epiphany.
  *
- * Epiphany is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * Epiphany is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  Epiphany is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
+ *  You should have received a copy of the GNU General Public License
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -28,7 +26,6 @@
 #include "ephy-embed-shell.h"
 #include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
-#include "ephy-private.h"
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -36,48 +33,48 @@
 static void
 test_ephy_embed_shell_launch_handler (void)
 {
-    EphyEmbedShell *embed_shell;
-    gboolean ret;
-    GFile *file;
+  EphyEmbedShell *embed_shell;
+  gboolean ret;
+  GFile *file;
 
-    embed_shell = ephy_embed_shell_get_default ();
+  embed_shell = ephy_embed_shell_get_default ();
 
-    ret = ephy_embed_shell_launch_handler (embed_shell, NULL, "text/html", 0);
-    g_assert (ret == FALSE);
+  ret = ephy_embed_shell_launch_handler (embed_shell, NULL, "text/html", 0);
+  g_assert (ret == FALSE);
 
-    file = g_file_new_for_path (TEST_DIR"/data/test.html");
-    g_assert (file);
+  file = g_file_new_for_path (TEST_DIR "/data/test.html");
+  g_assert (file);
 
-    ret = ephy_embed_shell_launch_handler (embed_shell, file, NULL, 0);
-    g_assert (ret == FALSE);
+  ret = ephy_embed_shell_launch_handler (embed_shell, file, NULL, 0);
+  g_assert (ret == FALSE);
 
-    ret = ephy_embed_shell_launch_handler (embed_shell, file, "text/html", 0);
-    g_assert (ret == FALSE);
+  ret = ephy_embed_shell_launch_handler (embed_shell, file, "text/html", 0);
+  g_assert (ret == FALSE);
 
-    g_object_unref (file);
+  g_object_unref (file);
 }
 
 static void
 web_view_created_cb (EphyEmbedShell *shell, EphyWebView *view, gpointer user_data)
 {
-    gboolean *web_view_created = (gboolean*)user_data;
-    *web_view_created = TRUE;
+  gboolean *web_view_created = (gboolean *)user_data;
+  *web_view_created = TRUE;
 }
 
 static void
 test_ephy_embed_shell_web_view_created (void)
 {
-    EphyEmbedShell *embed_shell;
-    GtkWidget *view;
-    gboolean web_view_created = FALSE;
+  EphyEmbedShell *embed_shell;
+  GtkWidget *view;
+  gboolean web_view_created = FALSE;
 
-    embed_shell = ephy_embed_shell_get_default ();
-    g_signal_connect (embed_shell, "web-view-created",
-                      G_CALLBACK (web_view_created_cb), &web_view_created);
+  embed_shell = ephy_embed_shell_get_default ();
+  g_signal_connect (embed_shell, "web-view-created",
+                    G_CALLBACK (web_view_created_cb), &web_view_created);
 
-    view = ephy_web_view_new ();
-    g_assert (web_view_created);
-    gtk_widget_destroy (view);
+  view = ephy_web_view_new ();
+  g_assert (web_view_created);
+  gtk_widget_destroy (view);
 }
 
 int
@@ -115,7 +112,7 @@ main (int argc, char *argv[])
 
   ephy_debug_init ();
 
-  if (!ephy_file_helpers_init (NULL, EPHY_FILE_HELPERS_PRIVATE_PROFILE | EPHY_FILE_HELPERS_ENSURE_EXISTS, NULL)) {
+  if (!ephy_file_helpers_init (NULL, EPHY_FILE_HELPERS_TESTING_MODE | EPHY_FILE_HELPERS_ENSURE_EXISTS, NULL)) {
     g_debug ("Something wrong happened with ephy_file_helpers_init()");
     return -1;
   }
